OiRA

Help

1. Příprava
2. Zapojení
3. Vyhledání rizik + Hodnocení rizik
4. Akční plán
5. Zpráva
6. Status 0%

# Zpráva o vyhledání a zhodnocení rizik

Po ukončení procesu vyhledání a zhodnocení rizik a vytvoření akčního plánu si můžete vygenerovat závěrečnou zprávu. Do textového pole pod tímto textem můžete napsat vaše komentáře a poznámky, které budou do zprávy zahrnuty

Uložit a pokračovat

Scroll to top
Back

## report.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More